@@ -31,6 +31,14 @@ impl<const L: usize> String<L> {
         &self
     }
 
+    pub fn as_bytes(&self) -> &[u8; L] {
+        &self.0
+    }
+
+    pub fn as_slice(&self) -> &[u8] {
+        self.as_str().as_bytes()
+    }
+
     /// Turns the `String` into its underlying bytes.
     pub fn into_bytes(self) -> [u8; L] {
         self.0
